"""Gives users direct access to functions."""
from lagrange.lagrange import lagrange, interpolate
